<?php

/*
 * LMS version 1.3.4 Terok
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netinfo.php,v 1.27 2004/03/11 17:24:22 lukasz Exp $
 */

if(!$LMS->NetworkExists($_GET['id']))
{
	header("Location: ?m=netlist");
	die;
}

if (isset($_SESSION['ntlp'][$_GET['id']]) && !isset($_GET['page']))
	$_GET['page'] = $_SESSION['ntlp'][$_GET['id']];

$_SESSION['ntlp'][$_GET['id']] = $_GET['page'];

$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'],1024);

$layout['pagetitle'] = "Informacja o sieci: ".$network['name'];

$SMARTY->assign('network',$network);
$SMARTY->display('netinfo.html');

?>
